==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketLifecycleRuleExpirationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketLifecycleRuleExpirationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property date Specifies the date after which you want the corresponding action to take effect.
 * @property days Specifies the number of days after object creation when the specific rule action takes effect.
 * @property expiredObjectDeleteMarker On a versioned bucket (versioning-enabled or versioning-suspended bucket), you can add this element in the lifecycle configuration to direct Amazon S3 to delete expired object delete markers. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
 */
public data class BucketLifecycleRuleExpirationArgs(
    public val date: Output<String>? = null,
    public val days: Output<Int>? = null,
    public val expiredObjectDeleteMarker: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketLifecycleRuleExpirationArgs> {
    override fun toJava(): com.pulumi.aws.s3.inputs.BucketLifecycleRuleExpirationArgs =
        com.pulumi.aws.s3.inputs.BucketLifecycleRuleExpirationArgs.builder()
            .date(date?.applyValue({ args0 -> args0 }))
            .days(days?.applyValue({ args0 -> args0 }))
            .expiredObjectDeleteMarker(expiredObjectDeleteMarker?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketLifecycleRuleExpirationArgs].
 */
@PulumiTagMarker
public class BucketLifecycleRuleExpirationArgsBuilder internal constructor() {
    private var date: Output<String>? = null

    private var days: Output<Int>? = null

    private var expiredObjectDeleteMarker: Output<Boolean>? = null

    /**
     * @param value Specifies the date after which you want the corresponding action to take effect.
     */
    @JvmName("ufmrolcumnejdnxv")
    public suspend fun date(`value`: Output<String>) {
        this.date = value
    }

    /**
     * @param value Specifies the number of days after object creation when the specific rule action takes effect.
     */
    @JvmName("fpytqnhjrjjcemwq")
    public suspend fun days(`value`: Output<Int>) {
        this.days = value
    }

    /**
     * @param value On a versioned bucket (versioning-enabled or versioning-suspended bucket), you can add this element in the lifecycle configuration to direct Amazon S3 to delete expired object delete markers. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
     */
    @JvmName("kpkppfjorjwkpcoa")
    public suspend fun expiredObjectDeleteMarker(`value`: Output<Boolean>) {
        this.expiredObjectDeleteMarker = value
    }

    /**
     * @param value Specifies the date after which you want the corresponding action to take effect.
     */
    @JvmName("igohaqthtlilnoyd")
    public suspend fun date(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.date = mapped
    }

    /**
     * @param value Specifies the number of days after object creation when the specific rule action takes effect.
     */
    @JvmName("sonragobhkxtgrck")
    public suspend fun days(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.days = mapped
    }

    /**
     * @param value On a versioned bucket (versioning-enabled or versioning-suspended bucket), you can add this element in the lifecycle configuration to direct Amazon S3 to delete expired object delete markers. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
     */
    @JvmName("qjcdgminopfnavqo")
    public suspend fun expiredObjectDeleteMarker(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expiredObjectDeleteMarker = mapped
    }

    internal fun build(): BucketLifecycleRuleExpirationArgs = BucketLifecycleRuleExpirationArgs(
        date = date,
        days = days,
        expiredObjectDeleteMarker = expiredObjectDeleteMarker,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketLifecycleRuleExpirationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketLifecycleRuleExpirationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property date Specifies the date after which you want the corresponding action to take effect.
 * @property days Specifies the number of days after object creation when the specific rule action takes effect.
 * @property expiredObjectDeleteMarker On a versioned bucket (versioning-enabled or versioning-suspended bucket), you can add this element in the lifecycle configuration to direct Amazon S3 to delete expired object delete markers. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
 */
public data class BucketLifecycleRuleExpirationArgs(
    public val date: Output<String>? = null,
    public val days: Output<Int>? = null,
    public val expiredObjectDeleteMarker: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketLifecycleRuleExpirationArgs> {
    override fun toJava(): com.pulumi.aws.s3.inputs.BucketLifecycleRuleExpirationArgs =
        com.pulumi.aws.s3.inputs.BucketLifecycleRuleExpirationArgs.builder()
            .date(date?.applyValue({ args0 -> args0 }))
            .days(days?.applyValue({ args0 -> args0 }))
            .expiredObjectDeleteMarker(expiredObjectDeleteMarker?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketLifecycleRuleExpirationArgs].
 */
@PulumiTagMarker
public class BucketLifecycleRuleExpirationArgsBuilder internal constructor() {
    private var date: Output<String>? = null

    private var days: Output<Int>? = null

    private var expiredObjectDeleteMarker: Output<Boolean>? = null

    /**
     * @param value Specifies the date after which you want the corresponding action to take effect.
     */
    @JvmName("wjadcvwidulttwsv")
    public suspend fun date(`value`: Output<String>) {
        this.date = value
    }

    /**
     * @param value Specifies the number of days after object creation when the specific rule action takes effect.
     */
    @JvmName("gksoyjdashixslsp")
    public suspend fun days(`value`: Output<Int>) {
        this.days = value
    }

    /**
     * @param value On a versioned bucket (versioning-enabled or versioning-suspended bucket), you can add this element in the lifecycle configuration to direct Amazon S3 to delete expired object delete markers. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
     */
    @JvmName("fusorodwujmmdjot")
    public suspend fun expiredObjectDeleteMarker(`value`: Output<Boolean>) {
        this.expiredObjectDeleteMarker = value
    }

    /**
     * @param value Specifies the date after which you want the corresponding action to take effect.
     */
    @JvmName("agduibhpxqdbnsmo")
    public suspend fun date(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.date = mapped
    }

    /**
     * @param value Specifies the number of days after object creation when the specific rule action takes effect.
     */
    @JvmName("ftjmxulcxlkasboq")
    public suspend fun days(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.days = mapped
    }

    /**
     * @param value On a versioned bucket (versioning-enabled or versioning-suspended bucket), you can add this element in the lifecycle configuration to direct Amazon S3 to delete expired object delete markers. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
     */
    @JvmName("forgdkyxvttgmmsj")
    public suspend fun expiredObjectDeleteMarker(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expiredObjectDeleteMarker = mapped
    }

    internal fun build(): BucketLifecycleRuleExpirationArgs = BucketLifecycleRuleExpirationArgs(
        date = date,
        days = days,
        expiredObjectDeleteMarker = expiredObjectDeleteMarker,
    )
}
